@@ -113,7 +113,7 @@ struct _ExoIconChooserModelItem
 
 
 
-static const gchar CONTEXT_NAMES[][14] =
+static const gchar CONTEXT_NAMES[][13] =
 {
   "Actions",        /* EXO_ICON_CHOOSER_CONTEXT_ACTIONS */
   "Animations",     /* EXO_ICON_CHOOSER_CONTEXT_ANIMATIONS */
@@ -122,10 +122,10 @@ static const gchar CONTEXT_NAMES[][14] =
   "Devices",        /* EXO_ICON_CHOOSER_CONTEXT_DEVICES */
   "Emblems",        /* EXO_ICON_CHOOSER_CONTEXT_EMBLEMS */
   "Emotes",         /* EXO_ICON_CHOOSER_CONTEXT_EMOTES */
-  "International",  /* EXO_ICON_CHOOSER_CONTEXT_INTERNATIONAL */
   "MimeTypes",      /* EXO_ICON_CHOOSER_CONTEXT_MIME_TYPES */
   "Places",         /* EXO_ICON_CHOOSER_CONTEXT_PLACES */
   "Status",         /* EXO_ICON_CHOOSER_CONTEXT_STATUS */
+  "Stock",          /* EXO_ICON_CHOOSER_CONTEXT_STOCK */
 };
 
 
@@ -188,7 +188,7 @@ exo_icon_chooser_model_finalize (GObject *object)
     }
 
   /* release all items */
-  g_list_foreach (model->items, (GFunc) exo_icon_chooser_model_item_free, NULL);
+  g_list_foreach (model->items, (GFunc) (void (*)(void)) exo_icon_chooser_model_item_free, NULL);
   g_list_free (model->items);
 
   (*G_OBJECT_CLASS (exo_icon_chooser_model_parent_class)->finalize) (object);
@@ -464,6 +464,17 @@ exo_icon_chooser_model_merge_symlinks (gpointer key,
 
 
 
+static gboolean
+icon_name_is_symbolic (const gchar *icon_name)
+{
+  return g_str_has_suffix (icon_name, "-symbolic")
+      || g_str_has_suffix (icon_name, "-symbolic-ltr")
+      || g_str_has_suffix (icon_name, "-symbolic-rtl")
+      || g_str_has_suffix (icon_name, ".symbolic");
+}
+
+
+
 static void
 exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
                                            ExoIconChooserModel *model)
@@ -502,6 +513,12 @@ exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
   icons = gtk_icon_theme_list_icons (icon_theme, NULL);
   for (lp = icons; lp != NULL; lp = lp->next)
     {
+      /* Skip symbolic icons since they lead to double processing */
+      if (icon_name_is_symbolic (lp->data))
+      {
+        continue;
+      }
+
       item = g_slice_new0 (ExoIconChooserModelItem);
       item->icon_name = lp->data;
       item->context = EXO_ICON_CHOOSER_CONTEXT_OTHER;
@@ -534,6 +551,12 @@ exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
       icons = gtk_icon_theme_list_icons (icon_theme, CONTEXT_NAMES[context]);
       for (lp = icons; lp != NULL; lp = lp->next)
         {
+          /* Skip symbolic icons since they lead to double processing */
+          if (icon_name_is_symbolic (lp->data))
+          {
+            continue;
+          }
+
           /* lookup the item in one of the hash tables */
           item = g_hash_table_lookup (items, lp->data);
           if (item == NULL)
@@ -678,7 +701,7 @@ _exo_icon_chooser_model_get_for_icon_theme (GtkIconTheme *icon_theme)
       g_object_set_data (G_OBJECT (icon_theme), "exo-icon-chooser-default-model", model);
 
       /* associated the model with the icon theme */
-      model->icon_theme = g_object_ref (G_OBJECT (icon_theme));
+      model->icon_theme = GTK_ICON_THEME (g_object_ref (G_OBJECT (icon_theme)));
       exo_icon_chooser_model_icon_theme_changed (icon_theme, model);
       g_signal_connect (G_OBJECT (icon_theme), "changed", G_CALLBACK (exo_icon_chooser_model_icon_theme_changed), model);
     }
